How to articles

### Navigation

- index
- next |
- previous |
- fantastico 0.1.0-b1 documentation »

# How to articles

- MVC How to
  - Code the model
  - Code the controller
  - Code the view
  - Test your application
- Deployment how to
  - Low usage (simplest scenario)
  - Low usage AWS
- Static assets
  - Static assets on dev
- Creating a new project
  - Create first component
  - Customize dev server
  - Customize uwsgi prod server